@@ -242,6 +242,11 @@ def ParseCreateOptionsBase(
       addons = {api_adapter.RAYOPERATOR: True}
     else:
       addons[api_adapter.RAYOPERATOR] = True
+  if getattr(args, 'enable_slurm_operator', None):
+    if addons is None:
+      addons = {api_adapter.SLURMOPERATOR: True}
+    else:
+      addons[api_adapter.SLURMOPERATOR] = True
   if getattr(args, 'enable_lustre_csi_driver', None):
     if addons is None:
       addons = {api_adapter.LUSTRECSIDRIVER: True}
@@ -340,6 +345,12 @@ def ParseCreateOptionsBase(
       labels=get_default('labels'),
       local_nvme_ssd_block=(local_nvme_ssd_block),
       local_ssd_count=get_default('local_ssd_count'),
+      maintenance_minor_version_disruption_interval=get_default(
+          'maintenance_minor_version_disruption_interval'
+          ),
+      maintenance_patch_version_disruption_interval=get_default(
+          'maintenance_patch_version_disruption_interval'
+          ),
       maintenance_window=get_default('maintenance_window'),
       maintenance_window_start=get_default('maintenance_window_start'),
       maintenance_window_end=get_default('maintenance_window_end'),
@@ -574,6 +585,7 @@ def ParseCreateOptionsBase(
       enable_auto_ipam=get_default('enable_auto_ipam'),
       enable_k8s_tokens_via_dns=get_default('enable_k8s_tokens_via_dns'),
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
+      disable_multi_nic_lustre=get_default('disable_multi_nic_lustre'),
       enable_lustre_multi_nic=get_default('enable_lustre_multi_nic'),
       enable_pod_snapshots=enable_pod_snapshots,
       enable_default_compute_class=get_default('enable_default_compute_class'),
@@ -584,6 +596,8 @@ def ParseCreateOptionsBase(
       ),
       network_tier=get_default('network_tier'),
       control_plane_egress_mode=get_default('control_plane_egress'),
+      enable_slice_controller=get_default('enable_slice_controller'),
+      autopilot_general_profile=get_default('autopilot_general_profile'),
   )
 
 GA = 'ga'
@@ -724,6 +738,9 @@ flags_to_add = {
         'logging': flags.AddLoggingFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -840,10 +857,9 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
-        'enableLustreMultiNic': (
-            lambda p: flags.AddEnableLustreMultiRailFlag(
-                p, hidden=True
-            )
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
         ),
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
@@ -853,9 +869,10 @@ flags_to_add = {
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
         ),
     },
     BETA: {
@@ -924,6 +941,9 @@ flags_to_add = {
         'legacyauth': flags.AddEnableLegacyAuthorizationFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -1057,27 +1077,28 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
-            p, hidden=True
+            p, hidden=False
         ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
-        'enableLustreMultiNic': (
-            lambda p: flags.AddEnableLustreMultiRailFlag(
-                p, hidden=True
-            )
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
         ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1157,6 +1178,9 @@ flags_to_add = {
         'maxnodes': flags.AddMaxNodesPerPool,
         'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -1284,27 +1308,28 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
-            p, hidden=True
+            p, hidden=False
         ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
-            lambda p: flags.AddEnableKernelModuleSignatureEnforcementFlag(
-                p, hidden=True
-            )
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
-        'enableLustreMultiNic': (
-            lambda p: flags.AddEnableLustreMultiRailFlag(
-                p, hidden=True
-            )
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
         ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
@@ -1669,6 +1694,7 @@ class CreateBeta(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1832,6 +1858,7 @@ class CreateAlpha(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1839,4 +1866,5 @@ class CreateAlpha(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.autopilot_general_profile = get_default('autopilot_general_profile')
     return ops
